<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/trunk/class/htdocs/datalist/PointerDataList.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Authors: Michael Clay <claym@osuosl.org>                               |
// |          Frederic Wenzel <fred@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id: PointerDataList.php 4717 2006-08-09 22:47:42Z schonstal $

/**
  * PointerDataList.php - contains the {@link PointerDataList} class
  *
  * @author $Author: schonstal $
  * @filesource
  * @package    htdocs
  * @subpackage datalists
  */

require_once(DAOEXT.'/pointer.php');
require_once(HTCLASS.'/DB_DataObjectDataList.php');
require_once(HTCLASS.'/DB_DataObjectDataListSource.php');

/**
  * Table listing for Pointers (forward and reverse)
  *
  * @link   http://phphtmllib.newsblob.com/javadoc.php phpHtmlLib API Documentation
  * @link   http://phphtmllib.newsblob.com/doc/phpHtmlLib/DefaultGUIDatalist.html
            DefaultGUIDataList API Documentation
  * @package    htdocs
  * @subpackage datalists
  */
class PointerDataList extends DB_DataObjectDataList
{

//{{{   get_data_source()

    /**
     *  This method is used to establish the object we're going to be displaying.
     */
    function get_data_source()
    {
        $pointer = new Pointer();
        $src = &new DB_DataObjectDataListSource($pointer);
        $this->set_data_source($src);
        $this->_default_orderby = 'hostname';
    }

//}}}
//{{{   _user_setup()

    /**
     *  This method is used to establish what columns we want to see from the 
     *  row and if we can sort or search for them.
     */
    function _user_setup()
    {
        $this->add_header_item(_("Hostname"), '15%', 'hostname', SORTABLE, SEARCHABLE);
        $this->add_header_item(_("IP Address"), '15%', 'ipaddress', SORTABLE, null);
        $this->add_header_item(_("TTL"),'15%','ttl',SORTABLE,null);
        $this->add_header_item(_("Type"),'15%','type',SORTABLE, null);
        $this->add_header_item(_("Status"),'15%','enabled',SORTABLE);
        $this->add_header_item(_("Action"),'15%');
        $this->_datasource->setup_db_options(array('zone' => $_SESSION['zone']));
    }

//}}}
//{{{   build_column_item()

    /**
     *  This method builds information for the columns for a given row.
     *
     *  @return Mixed   $obj    Object to be put in the column.
     */
    function build_column_item($row_data, $col_name)
    {
        global $conf;

        switch($col_name) {
            case _('Hostname'): //set the hostnames up as links to inspect them
                $link = web_root().'pointer.php?action=show&amp;id='.
                        $row_data['id'];
                $obj = html_a($link,$row_data[_('hostname')]);
                break; 
            case _('IP Address'):
                $obj = $row_data['ip'];
                break;
            case _('Action'): //static row is just links
                $obj = container();
                $obj = Module::apply_filter('action_module', $obj, $row_data, 'pointer');
                break;
            case _('Status'):
                $obj = ($row_data['enabled'] === 1? _('Enabled') : _('Disabled'));
                break;
            default:
                $obj = parent::build_column_item($row_data, $col_name);
        }

        return $obj;
    }

//}}}

}

?>
