<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2006 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id$

/**
 *  SOACreateForm.php - contains the {@link SOACreateForm} class
 *
 *  @author $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  This class is used for creating SOA Records
 *  
 *  @package    htdocs
 *  @subpackage forms
 */
class SOACreateForm extends MaintainForm
{

//{{{   vars
   
    /**
     *  Dirty cheat to map form elements to dbdo vars
     */
    var $map = array("Domain"=>"domain",
                    "Primary_Master"=>"primary_master",
                    "Hostmaster"=>"hostmaster",
                    "Delegated"=>"delegated",
                    "Refresh"=>"refresh",
                    "Retry"=>"retry",
                    "Expire"=>"expire",
                    "TTL"=>"ttl"
                    );
    
//}}}

//{{{   form_init_elements()

    /**
     *  This method initializes all of the elements of the form
     */
    function form_init_elements()
    {
        $domains    = new FEListBox(_("Domain"), true);
        $master     = new FEText(_("Primary Master"), true);
        $hostmaster = new FEText(_("Hostmaster"), true);
        $refresh    = new FEText(_("Refresh"), true);
        $retry      = new FEText(_("Retry"), true);
        $expire     = new FEText(_("Expire"), true);
        $ttl        = new FEText(_("TTL"), true);
        $delegated  = new FECheckbox(_("Delegated"));
   
        $domains->set_list_data($this->_domains());

        $this->add_elements($domains, $master, $hostmaster, $refresh, $retry,
            $expire, $ttl, $delegated);
        $this->set_action($_SERVER["SCRIPT_NAME"]);
        
    }
//}}}
//{{{   form_init_data()
    /*  Initialize the form elements. In create forms this is the global $conf
     *  defaults.
     *
     *  @global $conf
     */
    function form_init_data()
    {
        global $conf;
        $this->set_element_value(_("Primary Master"), $conf['soa']['primary_master']); 
        $this->set_element_value(_("Hostmaster"), $conf['soa']['hostmaster']); 
        $this->set_element_value(_("Refresh"), $conf['soa']['refresh']); 
        $this->set_element_value(_("Retry"), $conf['soa']['retry']); 
        $this->set_element_value(_("Expire"), $conf['soa']['expire']); 
        $this->set_element_value(_("TTL"), $conf['soa']['ttl']); 
    }
    
//}}}
//{{{   form_backend_validation()

    /**
     *  This method validates the values that were given before processing.
     *
     *  @return Boolean     True if data is valid
     */
    function form_backend_validation()
    {
        $vals = $this->get_all_element_values();
        $res = true;

        $domain = DB_Dataobject::Factory('domain');
        if (!$domain->get($vals[_('Domain')]))
            $this->add_error(_('Domain'),
                        _('Please choose a domain from the list'));

        $dbdobj = new SOA($_REQUEST['id']);
        $dbdobj->setAll();
        $dbdobj->setFrom($this->remap($vals, DBDO));
        
        $valid = $dbdobj->validate();
        
        if($valid !== true) {
            $errors = $this->remap($valid, FORM);
            foreach($errors as $label=>$error) {
                if($error !== true)
                    $this->add_error($label, $error);
            }
            $res = false;
        }

        return $res;
        
    }

//}}}
//{{{   form_action()

    /**
     *  This method is what processes the data after validation.  In this case
     *  it creates a SOA record.
     *
     *  @return Boolean     True if action was successful
     *  @global $user       User object
     */
    function form_action()
    {
        global $user;
        
        $res = true;
        
        switch(strtolower($this->get_action())) {
        
        case _("submit"):
            
            $vals = $this->get_all_element_values();
        
            $dbdobj = new SOA();
            $dbdobj->query("BEGIN");
            $dbdobj->setAll();
            $dbdobj->setFrom($this->remap($vals, DBDO));

            if(!$dbdobj->insert()) {
                $dbdobj->query("ROLLBACK");
                $res = false;
                $this->add_action(_("ERROR"), 
                        _("Failed to insert SOA Record into the database."));
            } else {
                $dbdobj->query("COMMIT");
                $dbdobj->write_history(_("SOA Record created"), ACTION_CREATE,
                                        $user->username);
            }
            break;

        default:
            die_hard(_("Invalid form action"));
            break;
        }

        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  This method lets them know they were successful in creating the record
     *  and allows them to go back to the index or to the list.
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a("index.php", _("[Return to Home]"));
        $link = html_a("soa.php", _("[Return to SOA List]"));
        $div->add(container(_("SOA Record created successfully!"),html_br()));
        $div->add(container($indlink, $link));
        return $div; 
    }

//}}}

/*Helper Methods*/
//{{{   _domains()

    /**
     *  Helper method.  Gets the domains the user has access too and uses that
     *  to populate the listbox of domains.
     *
     *  @return Array   Array of domains keyed by name
     */
    function _domains()
    {
        global $user;

        $domarray = array();
        
        $zd = DB_DataObject::Factory('zone_domain');
        if(!$user->is_admin())
            $zd->zone = $_SESSION['zone'];
        $dom = DB_DataObject::Factory('domain');
        $dom->joinAdd($zd);
        $dom->orderBy("name ASC");
        $dom->find();
        while($dom->fetch()) {
            $domarray[$dom->name] = $dom->domain;
        }

        return $domarray;
    }

//}}}

}

?>
