<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/trunk/class/htdocs/forms/UserAddForm.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Zack Bartel <bartel@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id: UserAddForm.php 4606 2006-07-12 22:41:37Z morgabra $

/**
 *  UserAddForm.php - contains the {@link UserAddForm} class
 *
 *  @author     $Author: morgabra $
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  This form is for adding local users
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class UserAddForm extends MaintainForm
{

//{{{   vars
    
    /**
     *  The map is used to map form labels to dbdo variables and vice versa.
     */
    var $map = array("Username"=>"username",
                    "Password"=>"password"
                    );

//}}}
//{{{   form_init_elements()
    
    /**
     *  This method is what makes and initializes the form elements
     */
    function form_init_elements()
    {
        $username = new FEText(_("Username"));
        $password = new UserPass(_("Password"));
        $confirm = new FEConfirmPassword(_("Confirm Password"));
        $confirm->password($password);

        $authtype = new FEListBox(_("Authentication Type"), false);
        $authtype->set_list_data($this->_get_auth_types());

        $this->add_elements($username, $password, $confirm, $authtype);
        $this->set_action($_SERVER['SCRIPT_NAME']);
    }

//}}}
    function _get_auth_types()
    {
        $result = array();
        $auths = Module::do_action('auth_modules'); 
        foreach ($auths as $a)
            $result[$a['result']] = $a['result'];
        return $result;
    }
//{{{   form_backend_validation()

    /**
     *  This method is used to make sure that the data is valid before it is
     *  processed into the database.
     *
     *  @return Boolean     True of the data is valid
     */
    function form_backend_validation()
    {
        $res = true;
    
        $dbdobj = new User();
        
        $dbdobj->setPassword($this->get_element_value(_("Password")));
        $dbdobj->setUsername($this->get_element_value(_("Username")));
        
        $dbdobj->setAll();

        $dbdobj->setType($this->get_element_value(_("Authentication Type")));
        
        
        $valid = $dbdobj->validate();
        
        if($valid !== true) {
            $res = false;
            
       $errors =  $this->remap($valid, FORM);  
            foreach($errors as $var=>$val) {
                if($val !== true)
                    $this->add_error($var,$val);
            }
        }
        return $res;
        
    }

//}}}
//{{{   form_action()

    /**
     *  This method runs after validation is complete and it does final processing
     *  on the data.
     *
     *  @return Boolean     True if the action is successful
     */
    function form_action()
    {
        global $user;

        $res = true;
        
        $values = $this->get_all_element_values();
      
        $dbdobj = new User();
        $dbdobj->query("BEGIN");
        $dbdobj->setUsername($values[_("Username")]);
        $dbdobj->setAll();
        $dbdobj->setType($this->get_element_value("Authentication Type"));
        $dbdobj->setPassword($values[_("Password")]);
        $valid = $dbdobj->insert();

        if(PEAR::isError($valid)) {
            $dbdobj->query("ROLLBACK");
            $res = false;
            $this->add_error("ERROR","Failed to add user to the database");
        } else {
            $dbdobj->query("COMMIT");
            $dbdobj->write_history(_("Added User"), ACTION_CREATE, $user->username,
                                    $dbdobj->preferred_zone);
        }

        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  If the form action is completed successfully we end up here.
     */
    function form_success()
    {
        header("Location: user.php?action=show&type=local");
    }

//}}}
//{{{   form_buttons()

    /**
     *  This method adds the buttons to the form
     *
     *  @param  String  $class  Class for the table row
     *
     *  @return TRTag   $tr     The table row that has the buttons
     */
    function form_buttons($class)
    {
        $tr = html_tr($class);
        $tr->add("&nbsp;", $this->add_action(_("Submit")));
        return $tr;
    }

//}}}
//{{{   form_hidden()

    /**
     *  This method adds the hidden elements to the form
     *
     *  @return FEHidden        The hidden element for action
     */
    function form_hidden()
    {
        $hidden = new FEHidden("action", "create");
        $this->add_element($hidden);

        return $this->element_form("action");
    }

//}}}
}

/**
 *  This class is extends FEPassword in order to overload the default password
 *  validation method which doesn't fit Maintain.
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class UserPass extends FEPassword
{

//{{{   validate()

    /**
     *  This is the overloaded validate method.  It just returns true, the real
     *  validation is handled by the DB_DataObjects.
     *
     *  @return true
     */
    function validate()
    {
        return true;
    }

//}}}

}

?>
