<?php

/* vim: set tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id: maintain_widgets.php 4851 2006-10-07 00:35:20Z jirwin $

/**
  * maintain_widgets.php - contains the {@link Maintain_Widgets} class
  *
  * @author $Author: $
  * @filesource
  * @package    modules
  * @subpackage maintain_widgets
  */

require_once MODDIR.'/core_module.php';

/**
  * This is the 'Maintain_Widgets' module for Maintain, providing a basic nav bar
  *
  * @package    modules
  * @subpackage maintain_widgets
  */
class Maintain_Widgets extends Core_Module {

//{{{ vars

//}}}

/* Overridden Module Methods */
// {{{ _install()

    /**
     *  This method takes care of operations that need to be carried out when the
     *  module is installed.  maintain_widgets requires nothing special.
     *
     *  @return Boolean true
     */
    function _install()
    {
        return true;
    }

// }}}
// {{{ _uninstall()

    /**
     *  This method takes care of operations that need to be carried out when the
     *  module is uninstalled.  maintain_widgets requires nothing special.
     *
     *  @return true
     */
    function _uninstall()
    {

        return true;

    }

// }}}
// {{{ register_hooks() (register methods to Maintain module hooks)

/**
  * Connect this module to the module hooks it should reply to
  *
  * @access public
  * @return void
  */
    function register_hooks()
    {
        Module::add_filter('dashboard','addHostWidget',0);
        Module::add_filter('dashboard','addZoneWidget',0);
        Module::add_filter('dashboard','addManageWidget',0);
        Module::add_filter('dashboard','addPermissionsWidget',0);
        Module::add_filter('dashboard','addReportWidget',0);
        Module::add_filter('dashboard','addModuleWidget',0);
        Module::add_filter('host_widget', 'populateHostWidget', 0); // priority 0: always on top
        Module::add_filter('zoneinfo_widget','populateZoneWidget',0);
        Module::add_filter('manage_widget','populateManageWidget',0);
        Module::add_filter('permissions_widget','populatePermissionsWidget',0);
        Module::add_filter('report_widget','populateReportWidget',0);
        Module::add_filter('admin_dashboard','addNetworkToolWidget',0);
        Module::add_filter('network_tools_widget','populateNetworkToolWidget',0);
        Module::add_filter('admin_dashboard','addGlobalStatsWidget',0);
        Module::add_filter('global_stats_widget','populateGlobalStatsWidget',0);
        Module::add_filter('admin_dashboard','addMiscToolsWidget',0);
        Module::add_filter('misc_tools_widget','populateMiscToolsWidget',0);
        Module::add_filter('admin_dashboard','addUserToolWidget',0);
        Module::add_filter('user_tool_widget','populateUserToolWidget',0);
        Module::add_filter('admin_dashboard','addAdminModuleWidget',0);
  //      Module::add_filter('admin_dashboard','makeTable',1);
    //    Module::add_filter('dashboard','makeTable',1); 
    }
// }}}

/* This module's methods */
/*Index Widgets*/
//{{{ populateHostWidget()

    /**
     *  This method makes the links and then puts them into the host widget
     *
     *  @return Widget  A populated widget
     */
    function populateHostWidget()
    {
        $args = func_get_args();
        if(!count($args))
            die("Note enough parameters passed to maintain_widget::populateHostWidget");
        $showHost = html_a(web_root()."host.php?action=show",_("Show Hosts"));
        $createHost = html_a(web_root()."host.php?action=create",_("Create a New Host"));
        $bulkUpdate = html_a(web_root()."host.php?action=update",_("Bulk Host Update"));
        $bulkDelete = html_a(web_root()."host.php?action=delete",_("Bulk Host Delete"));
        $args[0]->add($showHost);
        $args[0]->add($createHost);
        $args[0]->add($bulkUpdate);
        $args[0]->add($bulkDelete);

        return $args[0];
    }

//}}}
//{{{ populateZoneWidget()

    /**
     *  This method makes the links and then puts them into the zone widget
     *
     *  @return Widget  A populated widget
     */
    function populateZoneWidget()
    {
        $args = func_get_args();
        if(!count($args))
            die("Note enough parameters passed to maintain_widget::populateZoneWidget");
    
        //Count hosts
        $dbdo = DB_DataObject::Factory('host');
        $dbdo->zone = $_SESSION['zone'];
        $host_number = commify($dbdo->find());

        //Count CNAMES
        $dbdo = DB_DataObject::Factory('cname');
        $dbdo->zone = $_SESSION['zone'];
        $cname_number = commify($dbdo->find());

        //Count the MX Records
        $dbdo = DB_DataObject::Factory('mx');
        $dbdo->zone = $_SESSION['zone'];
        $mx_number = commify($dbdo->find());

        //Count the pointers
        $dbdo = DB_DataObject::Factory('pointer');
        $dbdo->zone = $_SESSION['zone'];
        $pointer_number = commify($dbdo->find());

        //Count the domains for this zone
        $dbdo = DB_DataObject::Factory('zone_domain');
        $dbdo->zone = $_SESSION['zone'];
        $domain_number = commify($dbdo->find());

        $args[0]->add(_("There are "). $host_number._(" Hosts in this zone"));
        $args[0]->add(_("There are "). $cname_number._(" CNAMES in this zone"));
        $args[0]->add(_("There are "). $mx_number._(" MX Records in this zone"));
        $args[0]->add(_("There are "). $pointer_number._(" Pointers in this zone"));
        $args[0]->add(_("There are "). $domain_number._(" Domains in this zone"));
        
        return $args[0]; 
    }

//}}}
//{{{ populateManageWidget()

    /**
     *  This method makes the links and then puts them into the management widget
     *
     *  @return Widget  A populated widget
     *  @global $user user object
     */
    function populateManageWidget()
    {
        global $user;
        
        $args = func_get_args();
        if(!count($args))
            die("Note enough parameters passed to maintain_widget::populateManageWidget");

        $args[0]->add(container(_("Pointers: "),
                            html_a(web_root()."pointer.php?action=show",_("Show")),
                            "|",html_a(web_root()."pointer.php?action=create",_("Create"))));
        $args[0]->add(container(_("CNAMES: "),
                            html_a(web_root()."cname.php?action=show",_("Show")),
                            "|",html_a(web_root()."cname.php?action=create",_("Create"))));
        $args[0]->add(container(_("MX: "),
                            html_a(web_root()."mx.php?action=show",_("Show")),
                            "|",html_a(web_root()."mx.php?action=create",_("Create"))));
        $args[0]->add(container(_("Workgroups: "),
                            html_a(web_root()."workgroup.php?action=show",_("Show")),
                            "|",html_a(web_root()."workgroup.php?action=create",_("Create"))));

        $domainc = container();
        $domainc->add(_("Domains: "), html_a(web_root()."domain.php?action=show",_("Show")));
        // only admins can create domains.
        if ($user->is_admin())
            $domainc->add("|",html_a(web_root()."domain.php?action=create",_("Create")));
        $args[0]->add($domainc);

        return $args[0];
    }

//}}}
//{{{ populatePermissionsWidget()

    /**
     *  This method makes the links and then puts them into the permissions widget
     *
     *  @return Widget  A populated widget
     */
    function populatePermissionsWidget()
    {
        $args = func_get_args();
        if(!count($args))
            die("Note enough parameters passed to maintain_widget::populatePermissionsWidget");
        
        $args[0]->add(html_a(web_root()."user.php?action=show_add",
                                        _("Add user to current zone")));
        $args[0]->add(html_a(web_root()."user.php?action=show&amp;type=zone",
                                _('View/Edit/Delete users from current zone')));
        $args[0]->add(html_a(web_root()."zone.php?action=purge&amp;id={$_SESSION['zone']}",_("Purge Hosts")));
        $args[0]->add(html_a(web_root()."zone.php?action=purge_zone&amp;id={$_SESSION['zone']}",
                                        _("Purge this zone")));

        return $args[0];
    }

//}}}
//{{{ populateReportWidget()

    /**
     *  This method makes the links and then puts them into the report widget
     *
     *  @return Widget  A populated widget
     */
    function populateReportWidget()
    {
        $args = func_get_args();
        if(!count($args))
            die("Note enough parameters passed to maintain_widget::populateReportWidget");

        $args[0]->add(html_a(web_root()."range.php",_("View IP Address Usage")));
        $args[0]->add(html_a(web_root()."zone.php?action=show_history",
                                _("Show "). $zone_obj->name._(" history")));

        return $args[0];
    }

//}}}
//{{{ addHostWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addHostWidget($dash)
    {
        global $skin;
        
        $host_widget =& $skin->getWidget();
        
        $host_widget->set_title(_("Manage Hosts"));
        $host_widget = Module::apply_filter('host_widget', $host_widget);

        $dash->add($host_widget);

        return $dash;
    }

//}}}
//{{{ addZoneWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addZoneWidget($dash)
    {
        global $skin;

        $zone_widget =& $skin->getWidget();

        $zone_widget->set_title(_("Zone Information"));
        $zone_widget = Module::apply_filter('zoneinfo_widget', $zone_widget);
        $dash->add($zone_widget);

        return $dash;
    }

//}}}
//{{{ addManageWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addManageWidget($dash)
    {
        global $skin;

        $manage_widget =& $skin->getWidget();
        $manage_widget->set_title(_("Manage Other Objects"));
        $manage_widget = Module::apply_filter('manage_widget', $manage_widget);
        $dash->add($manage_widget);

        return $dash;
    }

//}}}
//{{{ addPermissionsWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addPermissionsWidget($dash)
    {
        global $skin;

        $permissions_widget =& $skin->getWidget();
        $permissions_widget->set_title(_("Modify Permissions"));
        $permissions_widget = Module::apply_filter('permissions_widget', $permissions_widget);
        $dash->add($permissions_widget);

        return $dash;
    }

//}}}
//{{{ addReportWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addReportWidget($dash)
    {
        global $skin;

        $ri_widget =& $skin->getWidget();
        $ri_widget->set_title(_("Reporting and Information"));
        $ri_widget = Module::apply_filter('report_widget', $ri_widget);
        $dash->add($ri_widget);

        return $dash;
    }

//}}}
//{{{ addModuleWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addModuleWidget($dash)
    {
        global $skin;

        $widget = &$skin->getWidget();
        if($modWidget = Module::getDashboardItems()){
            $widget->add($modWidget); 
            $widget->set_title(_("Modules"));
            $widget = Module::apply_filter('modules_widget', $widget);
            $dash->add($widget);
        }
        return $dash;
    }

//}}}

/*Admin Widgets*/
//{{{ addNetworkTooldWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addNetworkToolWidget($dash)
    {
        global $skin;
        
        $widget =& $skin->getWidget();
        $widget->set_title(_("Network Tools"));
        $widget = Module::Apply_Filter('network_tools_widget',$widget);
        $dash->add($widget);

        return $dash;

    }

//}}}
//{{{ populateNetworkToolWidget()

    /**
     *  This method makes the links and then puts them into the network widget
     *
     *  @return Widget  A populated widget
     */
    function populateNetworkToolWidget($widget)
    {
        
        $widget->add(container(_("Manage IP Blocks: "),
                                html_a(web_root()."ip.php?action=show_admin",_("List")),
                                "|",
                                html_a(web_root()."ip.php?action=create",_("Create"))));
        $widget->add(container(_("Manage Subnets: "),
                                html_a(web_root()."subnet.php?action=show_admin",_("List")),
                                "|",
                                html_a(web_root()."subnet.php?action=create",_("Create"))));
        $widget->add(container(_("Manage Workgroups: "),
                                html_a(web_root()."workgroup.php?action=show_admin",_("List")),
                                "|",html_a(web_root()."workgroup.php?action=create",_("Create"))));
        $widget->add(container(_("Manage IP Ranges: "),
                                html_a(web_root()."range.php?action=show_admin",_("List")),
                                "|",
                                html_a(web_root()."range.php?action=create",_("Create"))));
        $widget->add(container(_("Manage Domains: "),
                                html_a(web_root()."domain.php?action=show_admin", _("List")),
                                "|",
                                html_a(web_root()."domain.php?action=create", _("Create"))));
        $widget->add(container(_("Manage VLAN's: "),
                                html_a(web_root()."vlan.php?action=show_admin",_("List")),
                                "|",html_a(web_root()."vlan.php?action=create",_("Create"))));
        $widget->add(container(_("Manage SOA records: "),
                                html_a(web_root()."soa.php?action=show",_("List")),
                                "|",html_a(web_root()."soa.php?action=create",_("Create"))));
        $widget->add(container(_("Manage DHCP Options: "),
                                html_a(web_root()."dhcp.php?action=show_admin",_("List")),
                                "|",
                                html_a(web_root()."dhcp.php?action=create",_("Create")),
                                "|",
                                html_a(web_root()."option.php?action=show&amp;object_type=global",_("Global"))));
        $widget->add(container(_("Manage Nameservers: "),
                                html_a(web_root()."ns.php?action=show",_("List")),
                                "|",
                                html_a(web_root()."ns.php?action=create",_("Create"))));
        return $widget;

    }

//}}}
//{{{ addGlobalStatsWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addGlobalStatsWidget($dash)
    {
        global $skin;

        $widget =& $skin->getWidget();
        $widget->set_title(_("Global Statistics"));
        $widget = Module::Apply_Filter('global_stats_widget',$widget);

        $dash->add($widget);

        return $dash;
    }

//}}}
//{{{ populateGlobalStatsWidget()

    /**
     *  This method makes the links and then puts them into the global stats widget
     *
     *  @return Widget  A populated widget
     */
    function populateGlobalStatsWidget($widget)
    {
        //Zone count
        $dbdo = DB_DataObject::Factory('zone');
        $zones      = $dbdo->find();

        //domain count
        $dbdo = DB_DataObject::Factory('domain');
        $domains    = $dbdo->find();

        //CNAME count
        $dbdo = DB_DataObject::Factory('cname');
        $cnames     = $dbdo->find();

        //MX Count
        $dbdo = DB_DataObject::Factory('mx');
        $mxs        = $dbdo->find();

        //Pointer Count
        $dbdo = DB_DataObject::Factory('pointer');
        $pointers   = $dbdo->find();

        //User Count
        $dbdo = DB_DataObject::Factory('zone_user');
        $dbdo->selectAdd();
        $dbdo->selectAdd('COUNT(DISTINCT(username)) as count');
        $dbdo->find(true);
        $users   = $dbdo->count;

        //Dynamic Host Count
        $dbdo = DB_DataObject::Factory('host');
        $dbdo->whereAdd('dynamic_range != 0');
        $dynamics   = $dbdo->find();

        //Static Host Count
        $dbdo = DB_DataObject::Factory('host');
        $dbdo->whereAdd('dynamic_range = 0');
        $statics   = $dbdo->find();

        //All Hosts count
        $hosts   = $statics + $dynamics;

        $widget->set_title(_("Current Global Statistics"));
        $widget->add(container(_("Zones: "), commify($zones)));
        $widget->add(container(_("Domains: "), commify($domains)));
        $widget->add(container(_("CNAME Records: "), commify($cnames)));
        $widget->add(container(_("MX Records: "), commify($mxs)));
        $widget->add(container(_("Pointer Records: "), commify($pointers)));
        $widget->add(container(_("Dynamic IP Hosts: "), commify($dynamics)));
        $widget->add(container(_("Static IP Hosts: "), commify($statics)));
        $widget->add(container(_("Total Hosts: "), commify($hosts)));
        $widget->add(container(_("Active Maintain Users: "), commify($users)));
        
        return $widget;
    }

//}}}
//{{{ addMiscToolsWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addMiscToolsWidget($dash)
    {
        global $skin;

        $widget =& $skin->getWidget();
        $widget->set_title(_('Misc. Tools'));
        $widget = Module::Apply_Filter('misc_tools_widget',$widget);
        $dash->add($widget);
        
        return $dash;
    }

//}}}
//{{{ populateMiscToolsWidget()

    /**
     *  This method makes the links and then puts them into the misc tools widget
     *
     *  @return Widget  A populated widget
     */
    function populateMiscToolsWidget($widget)
    {
        $widget->add(container(_("Zone Tools: "),
                                html_a(web_root()."zone.php?action=edit&amp;id={$_SESSION['zone']}",_("Edit Current")),
                                "|",
                                html_a(web_root()."zone.php?action=show",_("List")),
                                "|",
                                html_a(web_root()."zone.php?action=create",_("Create")),
                                "|",
                                html_a(web_root()."zone.php?action=show_merge",_("Merge"))));
                                
        $widget->add(container(_("Manage Hosts: "),
                                html_a(web_root()."host.php?action=select_bulk_host_zone_move",
                                        _("Bulk Host Zone Move")),
                                "|",
                                html_a(web_root()."range.php?action=show_batch_move",
                                        _("Batch Host Move")),
                                "|",
                                html_a(web_root()."range.php?action=show_batch_copy",
                                        _("Batch Host Copy"))));
                                        
        $widget->add(container(_("Help Documents: "),
                                html_a(web_root()."help.php?action=show",_("List")),
                                "|",
                                html_a(web_root()."help.php?action=create",_("Create"))));
                                
        $widget->add(container(_("Module Tools: "),
                                html_a(web_root()."modules.php",
                                        _("List/Enable/Disable Modules"))));

        $widget->add(container(_("History: "),
                                html_a(web_root()."zone.php?action=show_history",
                                        _("Zone History")),
                                "|",
                                html_a(web_root()."zone.php?action=show_all_history",
                                        _("All History"))));
        return $widget;
    }

//}}}
//{{{ addUserToolWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */
    function addUserToolWidget($dash)
    {
        global $skin;

        $widget =& $skin->getWIdget();
        $widget->set_title(_('User Tools'));
        $widget = Module::Apply_Filter('user_tool_widget',$widget);

        $dash->add($widget);

        return $dash;
    }

//}}}
//{{{ populateUserToolWidget()

    /**
     *  This method makes the links and then puts them into the user tools widget
     *
     *  @return Widget  A populated widget
     */
    function populateUserToolWidget($widget)
    {
        
        $widget->add(html_a(web_root()."user.php?action=show_add",
                                _("Add user to current zone")));
                                
        $widget->add(html_a(web_root()."zone.php?action=purge_hosts&amp;id=$zone",
                                _("Purge Hosts")));
                                
        $widget->add(html_a(web_root()."zone.php?action=purge&amp;id=$zone",_("Purge zone")));

        $widget->add(container(_("Manage Users: "),
                                html_a(web_root()."user.php?action=show",_("List All")),
                                "|",html_a(web_root()."user.php?action=show&amp;type=zone",
                                _("List Zone")),"|",
                                html_a(web_root()."user.php?action=create",_("Create"))));
                                
        $widget->add(html_a(web_root()."user.php?action=fulladmin", 
                                _("Add Full Administrator")));
                                
        return $widget;
    }

//}}}
//{{{ addAdminModuleWidget()

    /**
     *  This method gets a widget from the skin and adds it to the dashboard
     *
     *  @param  Container   Dashboard
     *  @return Container   Dashboard with the new widget added.
     */ 
    function addAdminModuleWidget($dash) 
    {
        global $skin;
    
        $widget =& $skin->getWidget();
        if($modWidget = Module::getDashboardItems('admin')){
            $widget->add($modWidget); 
            $widget->set_title(_("Modules"));
            $widget = Module::apply_filter('admin_module_widget', $widget);
            $dash->add($widget);
        }
        return $dash;
    }

//}}}

//{{{ makeTable()

    /**
     *  This method imposes a basic layout over the widgets to make them appear
     *  as they did in the previous Maintain releases.
     *
     *  @param  Container   $dash   Dashboard
     *  @return Container   $dash   Dashboard with the layout applied to it
     */
    function makeTable($dash)
    {
        $table = html_table("100%",0,7);
        $row = html_tr();
        for($i = 0; $i < $dash->count_content(); $i++)
        {
            $row->add($dash->get_element($i));
            if($i!=0 && $i%2 != 0)
            {
                $table->add($row);
                $row = html_tr();
            }
                
        }
        $dash = html_div("dashboard");
        $dash->add($table);
        return $dash;
    }

//}}}

}

?>
